@@ -225,14 +225,19 @@ def ParseCreateOptionsBase(
   addons = get_default('addons')
   if getattr(args, 'enable_backup_restore', None):
     if addons is None:
-      addons = api_adapter.BACKUPRESTORE
+      addons = {api_adapter.BACKUPRESTORE: True}
     else:
-      addons += api_adapter.BACKUPRESTORE
+      addons[api_adapter.BACKUPRESTORE] = True
   if getattr(args, 'enable_ray_operator', None):
     if addons is None:
-      addons = api_adapter.RAYOPERATOR
+      addons = {api_adapter.RAYOPERATOR: True}
     else:
-      addons += api_adapter.RAYOPERATOR
+      addons[api_adapter.RAYOPERATOR] = True
+  if getattr(args, 'enable_lustre_csi_driver', None):
+    if addons is None:
+      addons = {api_adapter.LUSTRECSIDRIVER: True}
+    else:
+      addons[api_adapter.LUSTRECSIDRIVER] = True
 
   return api_adapter.CreateClusterOptions(
       accelerators=get_default('accelerator'),
@@ -537,6 +542,11 @@ def ParseCreateOptionsBase(
           'enable_authorized_networks_on_private_endpoint'
       ),
       patch_update=get_default('patch_update'),
+      anonymous_authentication_config=get_default(
+          'anonymous_authentication_config'
+      ),
+      enable_auto_ipam=get_default('enable_auto_ipam'),
+      enable_k8s_tokens_via_dns=get_default('enable_k8s_tokens_via_dns'),
   )
 
 
@@ -775,6 +785,11 @@ flags_to_add = {
         ),
         'kubecontextOverride': flags.AddKubecontextOverrideFlag,
         'patchUpdate': flags.AddPatchUpdateFlag,
+        'anonymousAuthenticationConfig': (
+            flags.AddAnonymousAuthenticationConfigFlag
+        ),
+        'enableAutoIpam': lambda p: flags.AddAutoIpamFlag(p, hidden=True),
+        'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -917,9 +932,6 @@ flags_to_add = {
         'disablepodcidroverprovision': flags.AddDisablePodCIDROverprovisionFlag,
         'enableworkloadconfigaudit': flags.AddWorkloadConfigAuditFlag,
         'enableworkloadvulnscanning': flags.AddWorkloadVulnScanningFlag,
-        'podautoscalingdirectmetricsoptin': (
-            flags.AddPodAutoscalingDirectMetricsOptInFlag
-        ),
         'hpaprofile': flags.AddHPAProfilesFlag,
         'enableGoogleCloudAccess': flags.AddEnableGoogleCloudAccess,
         'managedConfig': flags.AddManagedConfigFlag,
@@ -968,6 +980,11 @@ flags_to_add = {
         ),
         'kubecontextOverride': flags.AddKubecontextOverrideFlag,
         'patchUpdate': flags.AddPatchUpdateFlag,
+        'anonymousAuthenticationConfig': (
+            flags.AddAnonymousAuthenticationConfigFlag
+        ),
+        'enableAutoIpam': lambda p: flags.AddAutoIpamFlag(p, hidden=True),
+        'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1117,9 +1134,6 @@ flags_to_add = {
         'disablepodcidroverprovision': flags.AddDisablePodCIDROverprovisionFlag,
         'enableworkloadconfigaudit': flags.AddWorkloadConfigAuditFlag,
         'enableworkloadvulnscanning': flags.AddWorkloadVulnScanningFlag,
-        'podautoscalingdirectmetricsoptin': (
-            flags.AddPodAutoscalingDirectMetricsOptInFlag
-        ),
         'enableGoogleCloudAccess': flags.AddEnableGoogleCloudAccess,
         'managedConfig': flags.AddManagedConfigFlag,
         'fleetProject': flags.AddFleetProjectFlag,
@@ -1167,6 +1181,11 @@ flags_to_add = {
         ),
         'kubecontextOverride': flags.AddKubecontextOverrideFlag,
         'patchUpdate': flags.AddPatchUpdateFlag,
+        'anonymousAuthenticationConfig': (
+            flags.AddAnonymousAuthenticationConfigFlag
+        ),
+        'enableAutoIpam': lambda p: flags.AddAutoIpamFlag(p, hidden=True),
+        'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
     },
 }
 
@@ -1447,9 +1466,6 @@ class CreateBeta(Create):
         'enable_workload_config_audit'
     )
     ops.performance_monitoring_unit = get_default('performance_monitoring_unit')
-    ops.pod_autoscaling_direct_metrics_opt_in = get_default(
-        'pod_autoscaling_direct_metrics_opt_in'
-    )
     ops.hpa_profile = get_default('hpa_profile')
     ops.enable_workload_vulnerability_scanning = get_default(
         'enable_workload_vulnerability_scanning'
@@ -1504,6 +1520,11 @@ class CreateBeta(Create):
         'disable_l4_lb_firewall_reconciliation'
     )
     ops.tier = get_default('tier')
+    ops.anonymous_authentication_config = get_default(
+        'anonymous_authentication_config'
+    )
+    ops.enable_auto_ipam = get_default('enable_auto_ipam')
+    ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     return ops
 
 
@@ -1602,9 +1623,6 @@ class CreateAlpha(Create):
         'enable_workload_config_audit'
     )
     ops.performance_monitoring_unit = get_default('performance_monitoring_unit')
-    ops.pod_autoscaling_direct_metrics_opt_in = get_default(
-        'pod_autoscaling_direct_metrics_opt_in'
-    )
     ops.hpa_profile = get_default('hpa_profile')
     ops.enable_workload_vulnerability_scanning = get_default(
         'enable_workload_vulnerability_scanning'
@@ -1656,4 +1674,9 @@ class CreateAlpha(Create):
         'disable_l4_lb_firewall_reconciliation'
     )
     ops.tier = get_default('tier')
+    ops.anonymous_authentication_config = get_default(
+        'anonymous_authentication_config'
+    )
+    ops.enable_auto_ipam = get_default('enable_auto_ipam')
+    ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     return ops
